gnucash maint: Multiple changes pushed
Christopher Lam
clam at code.gnucash.org
Wed Sep 14 19:26:49 EDT 2022
Updated via https://github.com/Gnucash/gnucash/commit/b2175611 (commit)
via https://github.com/Gnucash/gnucash/commit/1ddb4926 (commit)
via https://github.com/Gnucash/gnucash/commit/fe48d56a (commit)
via https://github.com/Gnucash/gnucash/commit/692cbfc8 (commit)
via https://github.com/Gnucash/gnucash/commit/9cd66451 (commit)
via https://github.com/Gnucash/gnucash/commit/6ceee1b8 (commit)
via https://github.com/Gnucash/gnucash/commit/f9f3717f (commit)
via https://github.com/Gnucash/gnucash/commit/eaa7824b (commit)
via https://github.com/Gnucash/gnucash/commit/e19308bd (commit)
from https://github.com/Gnucash/gnucash/commit/d167b017 (commit)
commit b21756119b74a62055d5b595bae54b969661c737
Merge: d167b017a 1ddb49263
Author: Christopher Lam <christopher.lck at gmail.com>
Date: Thu Sep 15 07:23:27 2022 +0800
Merge branch 'CDB-Man-changes' into maint #1431
commit 1ddb49263816bfd15a1bde6a1d88c62ac3242d2b
Author: Christopher Lam <christopher.lck at gmail.com>
Date: Wed Sep 14 23:54:58 2022 +0800
[assistant-stock-transaction] remove combined transactions types
They will be recorded separately.
* Dividend Reinvestment = Dividend + Long Buy
* Reverse Split with Cash-in-Lieu = Sell or Cover Buy + Reverse-Split
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index 1a67e1368..e266f99a5 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -196,34 +196,8 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing
// dividends issued to holder
N_("Dividend"),
- N_("Company issues cash dividends to holder.")
- },
- {
- FieldMask::ENABLED_DEBIT, // stock_amt
- FieldMask::ENABLED_DEBIT, // stock_val
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- true, // fees_capitalize
- FieldMask::ENABLED_CREDIT, // dividend_amt
- FieldMask::DISABLED, // capg_amt
- // Translators: this is a stock transaction describing
- // dividend issued to holder, and it may be reinvested. Some
- // dividends are distributed as cash.
- N_("Dividend reinvestment"),
- N_("Company issues dividend, which may be reinvested. Remaining non-reinvested dividends (if any) are paid out as a cash dividend.")
- },
- {
- FieldMask::ENABLED_DEBIT, // stock_amt
- FieldMask::ENABLED_DEBIT, // stock_val
- FieldMask::DISABLED, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- true, // fees_capitalize
- FieldMask::ENABLED_CREDIT, // dividend_amt
- FieldMask::DISABLED, // capg_amt
- // Translators: this is a stock transaction describing
- // dividend which is wholly reinvested.
- N_("Dividend reinvestment (without remainder) - N/A"),
- N_("Company issues dividend which is wholly reinvested.")
+ N_("Company issues cash dividends to holder.\n\nAny dividend being \
+reinvested must be subsequently recorded as a regular stock purchase.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -274,21 +248,12 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing a reverse split
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant.")
- },
- {
- FieldMask::ENABLED_CREDIT, // stock_amt
- FieldMask::ENABLED_CREDIT, // stock_val
- FieldMask::ENABLED_DEBIT, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- false, // fees_capitalize
- FieldMask::DISABLED, // dividend_amt
- FieldMask::ENABLED_CREDIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capgains_amt
- // Translators: this is a stock transaction describing a
- // reverse split. Some remainder stock units are returned as cash.
- N_("Reverse split with cash in lieu for remainder units"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
- },
+ N_("Company redeems units, thereby increasing the stock price by a \
+multiple, while keeping the total monetary value of the overall investment \
+constant.\n\nIf the reverse split results in a cash in lieu for remainder \
+units, please record the sale using the Stock Split Assistant first, then \
+record the reverse split.")
+ }
};
static const TxnTypeVec short_types
@@ -332,33 +297,6 @@ static const TxnTypeVec short_types
N_("Compensatory dividend"),
N_("Company issues dividends, and the short stock holder must make a compensatory payment for the dividend.")
},
- {
- FieldMask::ENABLED_CREDIT, // stock_amt
- FieldMask::ENABLED_CREDIT, // stock_val
- FieldMask::ENABLED_DEBIT, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- true, // fees_capitalize
- FieldMask::ENABLED_DEBIT, // dividend_amt
- FieldMask::DISABLED, // capg_amt
- // Translators: this is a stock transaction describing
- // dividends retrieved from holder when shorting stock. Some
- // dividends are recovered from holder
- N_("Dividend reinvestment (with remainder) - N/A"),
- N_("Company issues dividends to holder when shorting stock. Some dividends are recovered from holder")
- },
- {
- FieldMask::ENABLED_DEBIT, // stock_amt
- FieldMask::ENABLED_DEBIT, // stock_val
- FieldMask::DISABLED, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- true, // fees_capitalize
- FieldMask::ENABLED_DEBIT, // dividend_amt
- FieldMask::DISABLED, // capg_amt
- // Translators: this is a stock transaction describing
- // dividends retrieved from holder when shorting stock,
- N_("Dividend reinvestment (without remainder) - N/A"),
- N_("Company issues dividend when shorting stock, which are wholly recovered from holder.")
- },
{
FieldMask::DISABLED, // stock_amt
FieldMask::ENABLED_DEBIT, // stock_val
@@ -409,22 +347,12 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a
// reverse split when shorting stock.
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant.")
- },
- {
- FieldMask::ENABLED_DEBIT, // stock_amt
- FieldMask::ENABLED_DEBIT, // stock_val
- FieldMask::ENABLED_CREDIT, // cash_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
- false, // fees_capitalize
- FieldMask::DISABLED, // dividend_amt
- FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capg_amt
- // Translators: this is a stock transaction describing a
- // reverse split when shorting stock. Remainder stock
- // units are retrieved as cash.
- N_("Reverse split with cash in lieu remainder units"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
- },
+ N_("Company redeems units, thereby increasing the stock price by \
+a multiple, while keeping the total monetary value of the overall investment \
+constant.\n\nIf the reverse split results in a cash in lieu for remainder \
+units, please record the cover buy using the Stock Split Assistant first, \
+then record the reverse split.")
+ }
};
typedef struct
commit fe48d56a66fa2e1be0c1123f7d931016c3472528
Author: Christopher Lam <christopher.lck at gmail.com>
Date: Wed Sep 14 23:38:50 2022 +0800
[assistant-stock-transaction] if applicable, show price to insert
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index 43465b007..1a67e1368 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -736,7 +736,7 @@ refresh_page_finish (StockTransactionInfo *info)
gnc_numeric debit = gnc_numeric_zero ();
gnc_numeric credit = gnc_numeric_zero ();
- StringVec errors, warnings;
+ StringVec errors, warnings, infos;
SummaryLineInfo line;
// check the stock transaction date. If there are existing stock
@@ -798,6 +798,26 @@ to ensure proper recording."), new_date_str, last_split_date_str);
add_to_summary_table (list, line);
+ if (info->txn_type->stock_amount != FieldMask::DISABLED &&
+ info->txn_type->stock_value != FieldMask::DISABLED)
+ {
+ auto amt = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT(info->stock_amount_edit));
+ auto val = gnc_amount_edit_get_amount (GNC_AMOUNT_EDIT(info->stock_value_edit));
+ auto p = gnc_numeric_div (val, amt, GNC_DENOM_AUTO, GNC_HOW_DENOM_EXACT);
+ auto curr_pinfo = gnc_commodity_print_info (info->currency, true);
+ // Translators: %s refer to: stock mnemonic, broker currency,
+ // date of transaction.
+ auto tmpl = N_("A price of 1 %s = %s on %s will be recorded.");
+ auto date_str = qof_print_date (new_date);
+ auto price_str = g_strdup_printf
+ (_(tmpl),
+ gnc_commodity_get_mnemonic (xaccAccountGetCommodity (info->acct)),
+ xaccPrintAmount (p, curr_pinfo), date_str);
+ infos.emplace_back (price_str);
+ g_free (price_str);
+ g_free (date_str);
+ }
+
if (info->txn_type->cash_value != FieldMask::DISABLED)
{
check_page (line, debit, credit, info->txn_type->cash_value,
@@ -869,6 +889,8 @@ to ensure proper recording."), new_date_str, last_split_date_str);
auto summary = std::string { _(header) };
auto summary_add = [&summary](auto a) { summary += "\n⢠"; summary += a; };
std::for_each (errors.begin(), errors.end(), summary_add);
+ if (errors.empty())
+ std::for_each (infos.begin(), infos.end(), summary_add);
if (!warnings.empty())
{
auto warnings_header = N_ ("The following warnings exist:");
commit 692cbfc844deb15da6a94bc6ce6505c40165d581
Author: Christopher Lam <christopher.lck at gmail.com>
Date: Mon Sep 12 23:48:47 2022 +0800
[assistant-stock-transaction] add forgotten default memo
diff --git a/gnucash/gtkbuilder/assistant-stock-transaction.glade b/gnucash/gtkbuilder/assistant-stock-transaction.glade
index 30c982c9e..b21930132 100644
--- a/gnucash/gtkbuilder/assistant-stock-transaction.glade
+++ b/gnucash/gtkbuilder/assistant-stock-transaction.glade
@@ -823,6 +823,7 @@
<property name="can-focus">True</property>
<property name="hexpand">True</property>
<property name="invisible-char">â</property>
+ <property name="text" translatable="yes">Capital Gain</property>
</object>
<packing>
<property name="left-attach">1</property>
commit 9cd66451c2bbb51ca35f8ff69c21b6461b3b3589
Author: CDB-Man <CDB-Man at users.noreply.github.com>
Date: Mon Sep 12 02:21:03 2022 -0400
Update assistant-stock-transaction.cpp - reverse split remainders
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index ae5493285..b0946e6d1 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -201,7 +201,7 @@ static const TxnTypeVec long_types
{
FieldMask::ENABLED_DEBIT, // stock_amt
FieldMask::ENABLED_DEBIT, // stock_val
- FieldMask::ENABLED_DEBIT, // cash_amt
+ FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // cash_amt
FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO, // fees_amt
true, // fees_capitalize
FieldMask::ENABLED_CREDIT, // dividend_amt
@@ -210,7 +210,7 @@ static const TxnTypeVec long_types
// dividend issued to holder, and it may be reinvested. Some
// dividends are distributed as cash.
N_("Dividend reinvestment"),
- N_("Company issues dividend, which may be reinvested. Non-reinvested dividends are paid out as cash.")
+ N_("Company issues dividend, which may be reinvested. Remaining non-reinvested dividends (if any) are paid out as a cash dividend.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
commit f9f3717fdfd1e79d532773315a5ff5c3130e3212
Author: CDB-Man <CDB-Man at users.noreply.github.com>
Date: Sun Sep 11 18:13:48 2022 -0400
Update assistant-stock-transaction.cpp - consistent wording
Harmonizing some wording for consistency.
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index 0e1fe499d..ae5493285 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -262,7 +262,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a stock
// split
N_("Stock split"),
- N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the total monetary value the overall investment constant.")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the total monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -274,7 +274,7 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing a reverse split
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -287,7 +287,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a
// reverse split. Some fractional stock is returned as cash.
N_("Reverse split with cash in lieu for fractional unit remainders"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of overall investment constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
},
};
@@ -396,7 +396,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a stock
// split when shorting stock
N_("Stock split"),
- N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the monetary value of the overall investment constant.")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the total monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -409,7 +409,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a
// reverse split when shorting stock.
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -423,7 +423,7 @@ static const TxnTypeVec short_types
// reverse split when shorting stock. Fractional remaining
// stock is retrieved as cash.
N_("Reverse split with cash in lieu for fractionals"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
},
};
commit eaa7824b1598fc248648cbc46526ac158ae1e9f7
Author: CDB-Man <CDB-Man at users.noreply.github.com>
Date: Sun Sep 11 17:04:48 2022 -0400
Update assistant-stock-transaction.cpp
1. Remove $ currency signs to make it region agnostic
2. Remove the word "value" from stock splits and replace with "overall investment"
3. Remove $ signs from the compensatory return of capital and compensatory notional distribution transactions
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index 05ba54f5f..0e1fe499d 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -262,7 +262,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a stock
// split
N_("Stock split"),
- N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the $ value of shares constant.")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the total monetary value the overall investment constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -274,7 +274,7 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing a reverse split
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -287,7 +287,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a
// reverse split. Some fractional stock is returned as cash.
N_("Reverse split with cash in lieu for fractional unit remainders"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of overall investment constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
},
};
@@ -370,7 +370,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing return
// of capital retrieved from holder when shorting stock
N_("Compensatory return of capital"),
- N_("Company returns capital, and the short stock holder must make a compensatory payment for the returned capital. This reduces the cost basis (less negative towards $0) without affecting # units.")
+ N_("Company returns capital, and the short stock holder must make a compensatory payment for the returned capital. This reduces the cost basis (less negative, towards 0.00 value) without affecting # units.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -383,7 +383,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a
// notional distribution when shorting stock
N_("Compensatory notional distribution"),
- N_("Company issues a notional distribution, and the short stock holder must make a compensatory payment for the notional distribution. This is recorded as a loss/negative dividend income amount, and increases the cost basis (more negative away from $0) without affecting # units.")
+ N_("Company issues a notional distribution, and the short stock holder must make a compensatory payment for the notional distribution. This is recorded as a loss/negative dividend income amount, and increases the cost basis (more negative, away from 0.00 value) without affecting # units.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -396,7 +396,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a stock
// split when shorting stock
N_("Stock split"),
- N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the $ value of shares constant.")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -409,7 +409,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a
// reverse split when shorting stock.
N_("Reverse split"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -423,7 +423,7 @@ static const TxnTypeVec short_types
// reverse split when shorting stock. Fractional remaining
// stock is retrieved as cash.
N_("Reverse split with cash in lieu for fractionals"),
- N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the monetary value of the overall investment constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
},
};
commit e19308bd4933d8f6ce7c3460791d1bbfa6b7d888
Author: CDB-Man <CDB-Man at users.noreply.github.com>
Date: Sat Sep 10 20:04:48 2022 -0400
Pull request for updated wording
On the long side of the transaction list, dividend reinvestments with and without remainder can be merged.
On the short side of the transaction list, the 2 dividend reinvestment transactions are not relevant and should be deleted. There is no such thing as a "compensatory dividend reinvestment".
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index b0946e6d1..43465b007 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -168,7 +168,7 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // dividend_amt
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
- // purchase of stock.
+ // new purchase of stock.
N_("Buy"),
N_("Buying stock long.")
},
@@ -180,8 +180,8 @@ static const TxnTypeVec long_types
false, // fees_capitalize
FieldMask::DISABLED, // dividend_amt
FieldMask::ENABLED_CREDIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capgains_amt
- // Translators: this is a stock transaction describing sale of
- // stock, and recording capital gain/loss
+ // Translators: this is a stock transaction describing new
+ // sale of stock, and recording capital gain/loss
N_("Sell"),
N_("Selling stock long, and record capital gain/loss.")
},
@@ -285,8 +285,8 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // dividend_amt
FieldMask::ENABLED_CREDIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capgains_amt
// Translators: this is a stock transaction describing a
- // reverse split. Some fractional stock is returned as cash.
- N_("Reverse split with cash in lieu for fractional unit remainders"),
+ // reverse split. Some remainder stock units are returned as cash.
+ N_("Reverse split with cash in lieu for remainder units"),
N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
},
};
@@ -420,9 +420,9 @@ static const TxnTypeVec short_types
FieldMask::DISABLED, // dividend_amt
FieldMask::ENABLED_DEBIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capg_amt
// Translators: this is a stock transaction describing a
- // reverse split when shorting stock. Fractional remaining
- // stock is retrieved as cash.
- N_("Reverse split with cash in lieu for fractionals"),
+ // reverse split when shorting stock. Remainder stock
+ // units are retrieved as cash.
+ N_("Reverse split with cash in lieu remainder units"),
N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the total monetary value of the overall investment constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
},
};
commit 6ceee1b850cdef8b66057f550d3d71cc0546735c
Author: CDB-Man <CDB-Man at users.noreply.github.com>
Date: Mon Sep 12 02:04:16 2022 -0400
Update assistant-stock-transaction.cpp - dividend reinvestment
"Company issues dividend, which may be reinvested. Remaining non-reinvested dividends (if any) are paid out as a cash dividend.")
diff --git a/gnucash/gnome/assistant-stock-transaction.cpp b/gnucash/gnome/assistant-stock-transaction.cpp
index 91156a57d..05ba54f5f 100644
--- a/gnucash/gnome/assistant-stock-transaction.cpp
+++ b/gnucash/gnome/assistant-stock-transaction.cpp
@@ -138,9 +138,9 @@ static const TxnTypeVec starting_types
FieldMask::DISABLED, // dividend_amt
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing an
// Initial stock purchase
N_("Open buy"),
- N_("Initial stock purchase")
+ N_("Initial stock long purchase.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -151,9 +151,9 @@ static const TxnTypeVec starting_types
FieldMask::DISABLED, // dividend_amt
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing an
- // initial stock short-sale
+ // initial stock short sale
N_("Open short"),
- N_("Initial stock short-sale")
+ N_("Initial stock short sale.")
}
};
@@ -170,7 +170,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing
// purchase of stock.
N_("Buy"),
- N_("Buying stock.")
+ N_("Buying stock long.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -183,7 +183,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing sale of
// stock, and recording capital gain/loss
N_("Sell"),
- N_("Selling stock, and record capital gain/loss")
+ N_("Selling stock long, and record capital gain/loss.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -196,7 +196,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing
// dividends issued to holder
N_("Dividend"),
- N_("Company issues dividends to holder")
+ N_("Company issues cash dividends to holder.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -207,10 +207,10 @@ static const TxnTypeVec long_types
FieldMask::ENABLED_CREDIT, // dividend_amt
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
// dividend issued to holder, and is reinvested. Some
// dividends are distributed as cash.
- N_("Dividend reinvestment (with remainder)"),
- N_("Company issues dividend which is reinvested. Some dividends are paid to holder")
+ N_("Dividend reinvestment"),
+ N_("Company issues dividend, which may be reinvested. Non-reinvested dividends are paid out as cash.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -222,7 +222,7 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
// dividend which is wholly reinvested.
- N_("Dividend reinvestment (without remainder)"),
+ N_("Dividend reinvestment (without remainder) - N/A"),
N_("Company issues dividend which is wholly reinvested.")
},
{
@@ -235,8 +235,8 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing return
// of capital
- N_("Return of Capital"),
- N_("Stock returns capital to holder")
+ N_("Return of capital"),
+ N_("Company returns capital, reducing the cost basis without affecting # units.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -249,7 +249,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a
// notional distribution
N_("Notional distribution"),
- N_("Stock returns a notional distribution")
+ N_("Company issues a notional distribution, which is recorded as dividend income and increases the cost basis without affecting # units.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -262,7 +262,7 @@ static const TxnTypeVec long_types
// Translators: this is a stock transaction describing a stock
// split
N_("Stock split"),
- N_("Stock price is fractionally reduced")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the $ value of shares constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -274,7 +274,7 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing a reverse split
N_("Reverse split"),
- N_("Stock price is fractionally increased.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -286,8 +286,8 @@ static const TxnTypeVec long_types
FieldMask::ENABLED_CREDIT | FieldMask::ALLOW_ZERO | FieldMask::ALLOW_NEGATIVE, // capgains_amt
// Translators: this is a stock transaction describing a
// reverse split. Some fractional stock is returned as cash.
- N_("Reverse split with cash in lieu for fractionals"),
- N_("Stock price is fractionally increased. Fractional remaining stock is returned as cash.")
+ N_("Reverse split with cash in lieu for fractional unit remainders"),
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant. Any remainder units are sold/redeemed for cash, with a capital gain/loss realized.")
},
};
@@ -304,7 +304,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing
// shorting of stock.
N_("Short sell"),
- N_("Shorting stock.")
+ N_("Selling stock short.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -317,7 +317,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing cover
// buying stock, and recording capital gain/loss
N_("Buy to cover short"),
- N_("Buy back stock to cover short and record capital gain/loss")
+ N_("Buy back stock to cover short position, and record capital gain/loss.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -329,8 +329,8 @@ static const TxnTypeVec short_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
// dividends retrieved from holder when shorting stock
- N_("Compensatory Dividend"),
- N_("Company issues dividends to holder when shorting stock")
+ N_("Compensatory dividend"),
+ N_("Company issues dividends, and the short stock holder must make a compensatory payment for the dividend.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -343,7 +343,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing
// dividends retrieved from holder when shorting stock. Some
// dividends are recovered from holder
- N_("Dividend reinvestment (with remainder)"),
+ N_("Dividend reinvestment (with remainder) - N/A"),
N_("Company issues dividends to holder when shorting stock. Some dividends are recovered from holder")
},
{
@@ -356,7 +356,7 @@ static const TxnTypeVec short_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
// dividends retrieved from holder when shorting stock,
- N_("Dividend reinvestment (without remainder)"),
+ N_("Dividend reinvestment (without remainder) - N/A"),
N_("Company issues dividend when shorting stock, which are wholly recovered from holder.")
},
{
@@ -369,8 +369,8 @@ static const TxnTypeVec short_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing return
// of capital retrieved from holder when shorting stock
- N_("Compensatory Return of Capital"),
- N_("Return retrieves capital from holder when shorting stock")
+ N_("Compensatory return of capital"),
+ N_("Company returns capital, and the short stock holder must make a compensatory payment for the returned capital. This reduces the cost basis (less negative towards $0) without affecting # units.")
},
{
FieldMask::DISABLED, // stock_amt
@@ -382,8 +382,8 @@ static const TxnTypeVec short_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing a
// notional distribution when shorting stock
- N_("Compensatory Notional distribution"),
- N_("Stock retrieves a notional distribution")
+ N_("Compensatory notional distribution"),
+ N_("Company issues a notional distribution, and the short stock holder must make a compensatory payment for the notional distribution. This is recorded as a loss/negative dividend income amount, and increases the cost basis (more negative away from $0) without affecting # units.")
},
{
FieldMask::ENABLED_CREDIT, // stock_amt
@@ -396,7 +396,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a stock
// split when shorting stock
N_("Stock split"),
- N_("Stock price is fractionally reduced when shorting stock")
+ N_("Company issues additional units, thereby reducing the stock price by a divisor, while keeping the $ value of shares constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -409,7 +409,7 @@ static const TxnTypeVec short_types
// Translators: this is a stock transaction describing a
// reverse split when shorting stock.
N_("Reverse split"),
- N_("Stock price is fractionally increased when shorting stock.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant.")
},
{
FieldMask::ENABLED_DEBIT, // stock_amt
@@ -423,7 +423,7 @@ static const TxnTypeVec short_types
// reverse split when shorting stock. Fractional remaining
// stock is retrieved as cash.
N_("Reverse split with cash in lieu for fractionals"),
- N_("Stock price is fractionally increased when shorting stock. Fractional remaining stock is retrieved as cash.")
+ N_("Company redeems units, thereby increasing the stock price by a multiple, while keeping the $ value of shares constant. Any remainder units are closed and covered with a cash payment, with a capital gain/loss realized.")
},
};
Summary of changes:
@@ -138,9 +138,9 @@ static const TxnTypeVec starting_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing an
- // Initial stock purchase
+ // Initial stock long purchase
N_("Open buy"),
@@ -207,10 +207,10 @@ static const TxnTypeVec long_types
FieldMask::DISABLED, // capg_amt
// Translators: this is a stock transaction describing
- // dividend issued to holder, and is reinvested. Some
+ // dividend issued to holder, and it may be reinvested. Some
// dividends are distributed as cash.
gnucash/gnome/assistant-stock-transaction.cpp | 168 ++++++++-------------
.../gtkbuilder/assistant-stock-transaction.glade | 1 +
2 files changed, 60 insertions(+), 109 deletions(-)
More information about the gnucash-changes
mailing list